@@ -819,15 +819,20 @@ _build_time_vars = {'ABIFLAGS': '',
  'exec_prefix': '{BUILDROOT}',
  'prefix': '{BUILDROOT}',
  'srcdir': '.'}
-
-import pathlib, sys, platform, os, logging
+import pathlib
+import sys
+import platform
+import os
+import logging
 
 log = logging.getLogger(__name__)
 
+
 def build_arch():
     machine = platform.machine()
     return machine.lower()
 
+
 def get_triplet(machine=None, plat=None):
     if not plat:
         plat = sys.platform
@@ -843,7 +848,6 @@ def get_triplet(machine=None, plat=None):
         raise RelenvException("Unknown platform {}".format(platform))
 
 
-
 pydir = pathlib.Path(__file__).resolve().parent
 if sys.platform == "win32":
     DEFAULT_DATA_DIR = pathlib.Path.home() / "AppData" / "Local" / "relenv"
