@@ -1,15 +1,21 @@
-# Copyright 2023-2025 Broadcom.
+# Copyright 2022-2026 Broadcom.
 # SPDX-License-Identifier: Apache-2.0
 """
 Helper for building libraries to install into a relenv environment.
 """
+from __future__ import annotations
+
+import argparse
 import json
 import logging
+import os
 import sys
+from typing import Any, cast
 
 from .common import (
     MACOS_DEVELOPMENT_TARGET,
-    RelenvException,
+    PlatformError,
+    RelenvEnvironmentError,
     get_toolchain,
     get_triplet,
 )
@@ -17,7 +23,9 @@ from .common import (
 log = logging.getLogger()
 
 
-def setup_parser(subparsers):
+def setup_parser(
+    subparsers: argparse._SubParsersAction[argparse.ArgumentParser],
+) -> None:
     """
     Setup the subparser for the ``relenv buildenv`` command.
 
@@ -36,30 +44,33 @@ def setup_parser(subparsers):
     )
 
 
-def is_relenv():
+def is_relenv() -> bool:
     """
     True when we are in a relenv environment.
     """
     return hasattr(sys, "RELENV")
 
 
-def buildenv(relenv_path=None):
+def buildenv(
+    relenv_path: str | os.PathLike[str] | None = None,
+) -> dict[str, str]:
     """
     Relenv build environment variable mapping.
     """
     if not relenv_path:
         if not is_relenv():
-            raise RelenvException("Not in a relenv environment")
-        relenv_path = sys.RELENV
+            raise RelenvEnvironmentError("Not in a relenv environment")
+        relenv_path = cast(str | os.PathLike[str], cast(Any, sys).RELENV)
 
     if sys.platform != "linux":
-        raise RelenvException("buildenv is only supported on Linux")
+        raise PlatformError("buildenv is only supported on Linux")
 
     toolchain = get_toolchain()
     if not toolchain:
-        raise RelenvException("buildenv is only supported on Linux")
+        raise PlatformError("buildenv is only supported on Linux")
 
     triplet = get_triplet()
+    sysroot = f"{toolchain}/{triplet}/sysroot"
     env = {
         "RELENV_BUILDENV": "1",
         "TOOLCHAIN_PATH": f"{toolchain}",
@@ -67,30 +78,50 @@ def buildenv(relenv_path=None):
         "RELENV_PATH": f"{relenv_path}",
         "CC": f"{toolchain}/bin/{triplet}-gcc",
         "CXX": f"{toolchain}/bin/{triplet}-g++",
-        "CFLAGS": f"-I{relenv_path}/include -I{toolchain}/sysroot/usr/include",
-        "CXXFLAGS": (
+        "CFLAGS": (
+            f"--sysroot={sysroot} "
+            f"-fPIC "
             f"-I{relenv_path}/include "
-            f"-I{toolchain}/{triplet}/sysroot/usr/include "
-            f"-L{relenv_path}/lib -L{toolchain}/{triplet}/sysroot/lib "
+            f"-I{sysroot}/usr/include"
+        ),
+        "CXXFLAGS": (
+            f"--sysroot={sysroot} "
+            f"-fPIC "
+            f"-I{relenv_path}/include "
+            f"-I{sysroot}/usr/include "
+            f"-L{relenv_path}/lib -L{sysroot}/lib "
             f"-Wl,-rpath,{relenv_path}/lib"
         ),
         "CPPFLAGS": (
-            f"-I{relenv_path}/include " f"-I{toolchain}/{triplet}/sysroot/usr/include"
+            f"--sysroot={sysroot} "
+            f"-fPIC "
+            f"-I{relenv_path}/include "
+            f"-I{sysroot}/usr/include"
         ),
         "CMAKE_CFLAGS": (
-            f"-I{relenv_path}/include " f"-I{toolchain}/{triplet}/sysroot/usr/include"
+            f"--sysroot={sysroot} "
+            f"-fPIC "
+            f"-I{relenv_path}/include "
+            f"-I{sysroot}/usr/include"
         ),
         "LDFLAGS": (
-            f"-L{relenv_path}/lib -L{toolchain}/{triplet}/sysroot/lib "
+            f"--sysroot={sysroot} "
+            f"-L{relenv_path}/lib -L{sysroot}/lib "
             f"-Wl,-rpath,{relenv_path}/lib"
         ),
+        "CRATE_CC_NO_DEFAULTS": "1",
+        "OPENSSL_DIR": f"{relenv_path}",
+        "OPENSSL_INCLUDE_DIR": f"{relenv_path}/include",
+        "OPENSSL_LIB_DIR": f"{relenv_path}/lib",
+        "PKG_CONFIG_PATH": f"{relenv_path}/lib/pkgconfig",
+        "RUSTFLAGS": f"-L {relenv_path}/lib -C link-arg=-Wl,-rpath,{relenv_path}/lib",
     }
-    if sys.platform == "dawin":
+    if sys.platform == "darwin":
         env["MACOS_DEVELOPMENT_TARGET"] = MACOS_DEVELOPMENT_TARGET
     return env
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     """
     The entrypoint into the ``relenv buildenv`` command.
 
